==> aws-cdk-scala_2.12-0.9.0-sources.jar: io/burkard/cdk/cloudassembly/schema/AwsCloudFormationStackProperties.scala <==
package io.burkard.cdk.cloudassembly.schema

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object AwsCloudFormationStackProperties {

  def apply(
    templateFile: String,
    assumeRoleArn: Option[String] = None,
    validateOnSynth: Option[Boolean] = None,
    tags: Option[Map[String, String]] = None,
    terminationProtection: Option[Boolean] = None,
    assumeRoleExternalId: Option[String] = None,
    requiresBootstrapStackVersion: Option[Number] = None,
    stackName: Option[String] = None,
    lookupRole: Option[software.amazon.awscdk.cloudassembly.schema.BootstrapRole] = None,
    bootstrapStackVersionSsmParameter: Option[String] = None,
    parameters: Option[Map[String, String]] = None,
    stackTemplateAssetObjectUrl: Option[String] = None,
    cloudFormationExecutionRoleArn: Option[String] = None
  ): software.amazon.awscdk.cloudassembly.schema.AwsCloudFormationStackProperties =
    (new software.amazon.awscdk.cloudassembly.schema.AwsCloudFormationStackProperties.Builder)
      .templateFile(templateFile)
      .assumeRoleArn(assumeRoleArn.orNull)
      .validateOnSynth(validateOnSynth.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .tags(tags.map(_.asJava).orNull)
      .terminationProtection(terminationProtection.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .assumeRoleExternalId(assumeRoleExternalId.orNull)
      .requiresBootstrapStackVersion(requiresBootstrapStackVersion.orNull)
      .stackName(stackName.orNull)
      .lookupRole(lookupRole.orNull)
      .bootstrapStackVersionSsmParameter(bootstrapStackVersionSsmParameter.orNull)
      .parameters(parameters.map(_.asJava).orNull)
      .stackTemplateAssetObjectUrl(stackTemplateAssetObjectUrl.orNull)
      .cloudFormationExecutionRoleArn(cloudFormationExecutionRoleArn.orNull)
      .build()
}

==> aws-cdk-scala_2.13-0.15.0-sources.jar: io/burkard/cdk/cloudassembly/schema/AwsCloudFormationStackProperties.scala <==
package io.burkard.cdk.cloudassembly.schema

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object AwsCloudFormationStackProperties {

  def apply(
    templateFile: String,
    assumeRoleArn: Option[String] = None,
    validateOnSynth: Option[Boolean] = None,
    tags: Option[Map[String, String]] = None,
    terminationProtection: Option[Boolean] = None,
    assumeRoleExternalId: Option[String] = None,
    requiresBootstrapStackVersion: Option[Number] = None,
    stackName: Option[String] = None,
    lookupRole: Option[software.amazon.awscdk.cloudassembly.schema.BootstrapRole] = None,
    bootstrapStackVersionSsmParameter: Option[String] = None,
    parameters: Option[Map[String, String]] = None,
    stackTemplateAssetObjectUrl: Option[String] = None,
    cloudFormationExecutionRoleArn: Option[String] = None
  ): software.amazon.awscdk.cloudassembly.schema.AwsCloudFormationStackProperties =
    (new software.amazon.awscdk.cloudassembly.schema.AwsCloudFormationStackProperties.Builder)
      .templateFile(templateFile)
      .assumeRoleArn(assumeRoleArn.orNull)
      .validateOnSynth(validateOnSynth.map(Boolean.box).orNull)
      .tags(tags.map(_.asJava).orNull)
      .terminationProtection(terminationProtection.map(Boolean.box).orNull)
      .assumeRoleExternalId(assumeRoleExternalId.orNull)
      .requiresBootstrapStackVersion(requiresBootstrapStackVersion.orNull)
      .stackName(stackName.orNull)
      .lookupRole(lookupRole.orNull)
      .bootstrapStackVersionSsmParameter(bootstrapStackVersionSsmParameter.orNull)
      .parameters(parameters.map(_.asJava).orNull)
      .stackTemplateAssetObjectUrl(stackTemplateAssetObjectUrl.orNull)
      .cloudFormationExecutionRoleArn(cloudFormationExecutionRoleArn.orNull)
      .build()
}
